@@ -3,6 +3,7 @@ from .DropOldestDuplicates import DropOldestDuplicates
 from .GetMergeStatement import GetMergeStatement
 from .MockExtractor import MockExtractor
 from .MockLoader import MockLoader
+from .SelectAndCastColumns import SelectAndCastColumns
 
 __all__ = [
     DataframeCreator,
@@ -10,4 +11,5 @@ __all__ = [
     GetMergeStatement,
     MockExtractor,
     DropOldestDuplicates,
+    SelectAndCastColumns,
 ]
