@@ -1,3 +1,4 @@
+from datetime import timedelta
 from typing import List
 
 from atc_tools.testing import DataframeTestCase, TestHandle
@@ -19,11 +20,13 @@ class IncrementalExtractorTests(DataframeTestCase):
     date_row2 = dt_utc(2021, 1, 1, 10, 55)  # 1st of january 2021, 10:55
     date_row2Inc = dt_utc(2021, 1, 1, 10, 56)  # 1st of january 2021, 10:56
     date_row3 = dt_utc(2021, 1, 1, 11, 00)  # 1st of january 2021, 11:00
+    date_row4 = dt_utc(2021, 1, 5, 11, 00)  # 5th of january 2021, 11:00
 
     row1 = (1, "string1", date_row1)
     row2 = (2, "string2", date_row2)
     row2Inc = (22, "string2Inc", date_row2Inc)
     row3 = (3, "String3", date_row3)
+    row4 = (4, "String4", date_row4)
 
     # Test data for empty target or source
     source1 = [row1, row2, row3]
@@ -34,6 +37,11 @@ class IncrementalExtractorTests(DataframeTestCase):
     target1Inc = [row1, row2]
     extract1Inc = [row2Inc, row3]
 
+    # Test data for overlapping period
+    sourceOverlap = [row2, row3, row4]
+    targetOverlap = [row2, row3, row4]
+    extractOverlap = [row2, row3, row4]
+
     # The columns of the tables
     dummy_columns: List[str] = ["id", "stringcol", "timecol"]
 
@@ -192,3 +200,55 @@ class IncrementalExtractorTests(DataframeTestCase):
         df_extract = extractor.read()
 
         self.assertDataframeMatches(df_extract, None, self.extract1Inc)
+
+    def test_04_can_extract_with_overlap(self):
+        """
+        Source has the following data:
+
+        |id| stringcol    | timecol          |
+        |--|--------------|------------------|
+        |2 | "string2"    | 01.01.2021 10:55 |
+        |3|  "string3"    | 01.01.2021 11:00 |
+        |4 | "string4"    | 05.01.2021 11:00 |
+
+
+        Target has the following data:
+
+        |id| stringcol    | timecol          |
+        |--|--------------|------------------|
+        |2 | "string2"    | 01.01.2021 10:55 |
+        |3|  "string3"    | 01.01.2021 11:00 |
+        |4 | "string4"    | 05.01.2021 11:00 |
+
+        Since an overlap of 5 days id defined all data should have been read:
+
+        |id| stringcol    | timecol          |
+        |--|--------------|------------------|
+        |2 | "string2"    | 01.01.2021 10:55 |
+        |3|  "string3"    | 01.01.2021 11:00 |
+        |4 | "string4"    | 05.01.2021 11:00 |
+        """
+        source_test_handle = TestHandle(
+            provides=DataframeCreator.make_partial(
+                self.dummy_schema, self.dummy_columns, self.sourceOverlap
+            )
+        )
+
+        target_test_handle = TestHandle(
+            provides=DataframeCreator.make_partial(
+                self.dummy_schema, self.dummy_columns, self.targetOverlap
+            )
+        )
+
+        extractor = IncrementalExtractor(
+            handle_source=source_test_handle,
+            handle_target=target_test_handle,
+            time_col_source="timecol",
+            time_col_target="timecol",
+            dataset_key="source",
+            overlap_period=timedelta(days=5),
+        )
+
+        df_extract = extractor.read()
+
+        self.assertDataframeMatches(df_extract, None, self.extractOverlap)
